define(["require", "exports", "react", "../../utilities/rtl", "./index", "enzyme", "chai"], function (require, exports, React, rtl_1, index_1, enzyme_1, chai) {
    "use strict";
    var expect = chai.expect;
    describe('Persona', function () {
        describe('initials and colors', function () {
            beforeEach(function () {
                rtl_1.setRTL(false);
            });
            it('renders with expected initialsColor if none was provided', function () {
                var wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Kat Larrson' }));
                var result = wrapper.find('.ms-Persona-initials--red');
                expect(result).to.have.length(1);
                var wrapper2 = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Annie Lindqvist' }));
                result = wrapper2.find('.ms-Persona-initials--darkRed');
                expect(result).to.have.length(1);
            });
            it('uses provided initialsColor if one was specified', function () {
                var wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Kat Larrson', initialsColor: index_1.PersonaInitialsColor.lightBlue }));
                var result = wrapper.find('.ms-Persona-initials--lightBlue');
                expect(result).to.have.length(1);
            });
            it('calculates an expected initials in LTR if one was not specified', function () {
                var wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Kat Larrson' }));
                var result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('KL');
                wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'David Zearing-Goff' }));
                result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('DZ');
                wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: '4lex 4loo' }));
                result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('44');
                wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'David (The man) Goff' }));
                result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('D');
            });
            it('calculates an expected initials in RTL if one was not specified', function () {
                rtl_1.setRTL(true);
                var wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Kat Larrson' }));
                var result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('LK');
                rtl_1.setRTL(false);
            });
            it('uses provided initial', function () {
                rtl_1.setRTL(true);
                var wrapper = enzyme_1.shallow(React.createElement(index_1.Persona, { primaryText: 'Kat Larrson', imageInitials: 'AT' }));
                var result = wrapper.find('.ms-Persona-initials');
                expect(result).to.have.length(1);
                expect(result.text()).to.equal('AT');
                rtl_1.setRTL(false);
            });
        });
    });
});

//# sourceMappingURL=Persona.test.js.map
